@@ -13,14 +13,18 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, write to the 
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
+
+#define _DEFAULT_SOURCE
+
 #include "config.h"
 
 #include <string.h>
 #include <stdlib.h>
-#ifdef HAVE_GD
+#ifdef HAVE_LIBGD
 #include <gd.h>
 #endif
 
@@ -163,7 +167,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 {
 	Camera *camera = data;
 	int idx, size;
-#ifdef HAVE_GD
+#ifdef HAVE_LIBGD
 	int ret;
 	gdImagePtr im;
 	void *gdpng;
@@ -186,7 +190,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		return GP_OK;
 	}
 
-#ifdef HAVE_GD
+#ifdef HAVE_LIBGD
 	if (type != GP_FILE_TYPE_NORMAL)
 		return GP_ERROR_NOT_SUPPORTED;
 
@@ -224,7 +228,7 @@ static int
 put_file_func (CameraFilesystem *fs, const char *folder, const char *name, 
 	CameraFileType type, CameraFile *file, void *data, GPContext *context)
 {
-#ifdef HAVE_GD
+#ifdef HAVE_LIBGD
 	Camera *camera = data;
 	char *filedata = NULL;
 	int ret, in_width, in_height, in_x, in_y;
@@ -358,7 +362,7 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 {
 	Camera *camera = data; 
 	int i, count, present;
-	char buf[16];
+	char buf[30];
 
 	count = ax203_read_filecount (camera);
 	if (count < 0) return count;
@@ -537,12 +541,19 @@ camera_init (Camera *camera, GPContext *context)
 		  ax203_get_free_mem_size (camera));
 
 	if (camera->pl->syncdatetime) {
+		struct tm *xtm;
+#ifdef HAVE_LOCALTIME_R
 		struct tm tm;
+#endif
 		time_t t;
 
 		t = time (NULL);
-		if (localtime_r (&t , &tm)) {
-			ret = ax203_set_time_and_date (camera, &tm);
+#ifdef HAVE_LOCALTIME_R
+		if ((xtm = localtime_r (&t , &tm))) {
+#else
+		if ((xtm = localtime (&t))) {
+#endif
+			ret = ax203_set_time_and_date (camera, xtm);
 			if (ret != GP_OK) {
 				camera_exit (camera, context);
 				return ret;
