@@ -30,6 +30,11 @@
 #include <gphoto2/gphoto2-result.h>
 #include "gphoto2-endian.h"
 
+#ifdef FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION
+#define sleep(x)
+#define usleep(x)
+#endif
+
 #ifdef ENABLE_NLS
 #  include <libintl.h>
 #  undef _
