@@ -1869,6 +1869,8 @@ camera_init (Camera *camera, GPContext *context)
 {
 	GPPortInfo      info;
 	int		ret;
+	int		tries;
+	char		*result;
 
 	camera->pl = calloc(sizeof(CameraPrivateLibrary),1);
 
@@ -1893,12 +1895,14 @@ camera_init (Camera *camera, GPContext *context)
 	}
 	gp_filesystem_set_funcs (camera->fs, &fsfuncs, camera);
 
-/*
-	startup code might need:
-
-	loadCmd(camera,"cam.cgi?mode=accctrl&type=req_acc&value=4D454930-0100-1000-8001-020D0090325B&value2=GT-I9300");
-	loadCmd(camera,"cam.cgi?mode=setsetting&type=device_name&value=GT-I9300");
-*/
+	tries = 3;
+	while (tries--) {
+		result = loadCmd(camera,"cam.cgi?mode=accctrl&type=req_acc&value=0&value2=libgphoto2/lumix");
+		if (strstr(result,"ok,")) {
+			loadCmd(camera,"cam.cgi?mode=setsetting&type=device_name&value=libgphoto2/lumix");
+			break;
+		}
+	}
 
 	if (switchToRecMode (camera) != NULL) {
 		int numpix;
