@@ -1,5 +1,5 @@
 /*
- * Copyright  1999/2000 by Henning Zabel <henning@uni-paderborn.de>
+ * Copyright 1999/2000 by Henning Zabel <henning@uni-paderborn.de>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -124,7 +124,7 @@ int mdc800_rs232_waitForCommit (GPPort *port,char commandid)
 	int ret;
 
 	gp_port_set_timeout(port,mdc800_io_getCommandTimeout(commandid));
-	ret = gp_port_read(port,ch,1);
+	ret = gp_port_read(port,(char *)ch,1);
 	if (ret!=1)
 	{
 		printCError ("(mdc800_rs232_waitForCommit) Error receiving commit !\n");
