@@ -21,7 +21,7 @@
  * XDISCVRY.X3C file sent on start, empty.
  */
 
-#define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 
 #include "config.h"
 
@@ -223,7 +223,7 @@ scsi_wrap_cmd(
 #define PTP_DP_DATA_MASK        0x00ff  /* data phase mask */
 
 static uint16_t
-ums_wrap_sendreq (PTPParams* params, PTPContainer* req) {
+ums_wrap_sendreq (PTPParams* params, PTPContainer* req, int dataphase) {
 	Camera			*camera = ((PTPData *)params->data)->camera;
 	PTPUSBBulkContainer	usbreq;
 	char			buf[64];
@@ -557,6 +557,7 @@ traverse_tree (PTPParams *params, int depth, xmlNodePtr node) {
 		ptp_debug(params,"%scontent %s", xx, xchar);
 		traverse_tree (params, depth+1,xmlFirstElementChild (next));
 	} while ((next = xmlNextElementSibling (next)));
+	free (xx);
 	return TRUE;
 }
 
@@ -873,7 +874,7 @@ traverse_output_tree (PTPParams *params, xmlNodePtr node, PTPContainer *resp) {
 		return FALSE;
 	}
 	if (xmlChildElementCount(node) != 2) {
-		GP_LOG_E ("output: expected 2 childs, got %ld.", xmlChildElementCount(node));
+		GP_LOG_E ("output: expected 2 children, got %ld.", xmlChildElementCount(node));
 		return FALSE;
 	}
 	next = xmlFirstElementChild (node);
@@ -973,7 +974,7 @@ traverse_input_tree (PTPParams *params, xmlNodePtr node, PTPContainer *resp) {
 				if (curpar < sizeof(pars)/sizeof(pars[0]))
 					pars[curpar++] = x;
 				else
-					GP_LOG_E ("ignore superflous argument %s/%x", (char*)xmlNodeGetContent(next), x);
+					GP_LOG_E ("ignore superfluous argument %s/%x", (char*)xmlNodeGetContent(next), x);
 			}
 			next = xmlNextElementSibling (next);
 			continue;
@@ -1291,11 +1292,11 @@ ums_wrap2_event_check (PTPParams* params, PTPContainer* req)
 }
 
 static uint16_t
-ums_wrap2_sendreq (PTPParams* params, PTPContainer* req)
+ums_wrap2_sendreq (PTPParams* params, PTPContainer* req, int dataphase)
 {
 	GP_LOG_D ("ums_wrap2_sendreq");
 	if (is_outer_operation (params,req->Code))
-		return ums_wrap_sendreq (params,req);
+		return ums_wrap_sendreq (params,req,dataphase);
 	/* We do stuff in either senddata, getdata or getresp, not here. */
 	params->olympus_cmd   = NULL;
 	params->olympus_reply = NULL;
