@@ -13,15 +13,16 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, write to the 
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 #ifndef __ST2205_H__
 #define __ST2205_H__
 #include "config.h"
 
 #include <stdio.h>
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 #include <iconv.h>
 #endif
 
@@ -72,6 +73,19 @@ struct st2205_coord {
 	uint16_t y;
 };
 
+struct st2205_image_header {
+	uint8_t marker;   /* Always 0xF5 */
+	uint16_t width;	  /* big endian */
+	uint16_t height;  /* big endian */
+	uint16_t blocks;  /* number of 8x8 blocks in the image, big endian */
+	uint8_t shuffle_table; /* shuffle table idx (for transition effects) */
+	uint8_t unknown2; /* Unknown usually 0x04 */
+	uint8_t unknown3; /* shuffle related, must have a special value depend
+			     on the pattern see the table in st2205_init */
+	uint16_t length;  /* length of the data *following* the header (be) */
+	uint8_t unknown4[4]; /* Always 4x 0x00 (padding ?) */
+} __attribute__((packed));
+
 #define CHECK(result) {int r=(result); if (r<0) return (r);}
 
 /* The + 5 is space for the "####-" prefix we add, + 4 for .png postfix. */
@@ -80,7 +94,7 @@ typedef int16_t st2205_lookup_row[8];
 
 struct _CameraPrivateLibrary {
 	/* Used by library.c glue code */
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 	iconv_t	cd;
 #endif
 	st2205_filename filenames[ST2205_MAX_NO_FILES];
@@ -102,13 +116,16 @@ struct _CameraPrivateLibrary {
 	int no_fats;
 	int block_is_present[2097152 / ST2205_BLOCK_SIZE];
 	int block_dirty[2097152 / ST2205_BLOCK_SIZE];
-	st2205_lookup_row lookup[3][256];
 	struct st2205_coord shuffle[8][ST2205_SHUFFLE_SIZE];
 	int no_shuffles;
 	unsigned char unknown3[8];
 	unsigned int rand_seed;
 };
 
+/* tables in st2205_tables.c */
+extern const st2205_lookup_row st2205_lookup[3][256];
+extern const uint8_t st2205_shuffle_data[10360];
+
 /* functions in st2205.c */
 int
 st2205_open_device(Camera *camera);
@@ -153,8 +170,7 @@ st2205_get_free_mem_size(Camera *camera);
 
 /* functions in st2205_decode.c */
 int
-st2205_decode_image(CameraPrivateLibrary *pl, unsigned char *src,
-	int src_length, int **dest, uint8_t shuffle_pattern);
+st2205_decode_image(CameraPrivateLibrary *pl, unsigned char *src, int **dest);
 
 int
 st2205_code_image(CameraPrivateLibrary *pl, int **src,
