@@ -15,15 +15,16 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with puppy; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  along with puppy; if not, write to the 
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
 */
 
 #ifndef _TF_BYTES_H
 #define _TF_BYTES_H 1
 
-#include <stdint.h>
+#include <_stdint.h>
 
 unsigned short get_u16(void *addr);
 unsigned short get_u16_raw(void *addr);
