@@ -10,7 +10,6 @@
  * Taken from: http://credentiality2.blogspot.com/2008/07/linux-libgphoto2-image-capture-from.html 
  */
 
-#include <unistd.h>
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -101,7 +100,7 @@ capture_to_file(Camera *canon, GPContext *canoncontext, char *fn) {
 
 	printf("Pathname on the camera: %s/%s\n", camera_file_path.folder, camera_file_path.name);
 
-	fd = open(fn, O_CREAT | O_WRONLY, 0644);
+	fd = open(fn, O_CREAT | O_WRONLY | O_BINARY, 0644);
 	retval = gp_file_new_from_fd(&canonfile, fd);
 	printf("  Retval: %d\n", retval);
 	retval = gp_camera_file_get(canon, camera_file_path.folder, camera_file_path.name,
@@ -138,6 +137,11 @@ main(int argc, char **argv) {
 		exit (1);
 	}
 	canon_enable_capture(canon, TRUE, canoncontext);
+	retval = camera_eosviewfinder(canon,canoncontext,1);
+	if (retval != GP_OK) {
+		fprintf(stderr,"camera_eosviewfinder(1): %d\n", retval);
+		exit(1);
+	}
 	/*set_capturetarget(canon, canoncontext);*/
 	printf("Taking 100 previews and saving them to snapshot-XXX.jpg ...\n");
 	for (i=0;i<100;i++) {
@@ -153,7 +157,9 @@ main(int argc, char **argv) {
 
 		/* autofocus every 10 shots */
 		if (i%10 == 9) {
-			camera_auto_focus (canon, canoncontext);
+			camera_auto_focus (canon, canoncontext, 1);
+			/* FIXME: wait a bit and/or poll events ? */
+			camera_auto_focus (canon, canoncontext, 0);
 		} else {
 			camera_manual_focus (canon, (i/10-5)/2, canoncontext);
 		}
@@ -183,6 +189,13 @@ main(int argc, char **argv) {
 	        capture_to_file(canon, canoncontext, output_file);
 	*/
 	}
+	retval = camera_eosviewfinder(canon,canoncontext,0);
+	if (retval != GP_OK) {
+		fprintf(stderr,"camera_eosviewfinder(0): %d\n", retval);
+		exit(1);
+	}
+
+	sleep(10);
 	gp_camera_exit(canon, canoncontext);
 	return 0;
 }
