@@ -2,6 +2,10 @@
 #define __SAMPLES_H
 #include <gphoto2/gphoto2-camera.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern int sample_autodetect (CameraList *list, GPContext *context);
 extern int sample_open_camera (Camera ** camera, const char *model, const char *port, GPContext *context);
 extern GPContext* sample_create_context(void);
@@ -19,4 +23,8 @@ extern int camera_manual_focus (Camera *list, int tgt, GPContext *context);
 	#define O_BINARY 0
 #endif
 
+#ifdef __cplusplus
+};
+#endif
+
 #endif
